@@ -290,7 +290,7 @@ sub is_in_sync_mask ($$) {
 # by default the version of a module is the fvwm version
 sub version ($) {
 	my $self = shift;
-	return "1.0.6a";
+	return "1.0.8";
 }
 
 sub version_info ($) {
